@@ -9,7 +9,7 @@ class HltVisitHistory(BaseModel):
     uuid = models.CharField(db_column='GUID', max_length=36, unique=True, default=uuid.uuid4)
     date = models.DateTimeField(db_column='Date')
     is_complete = models.BooleanField(db_column='IsComplete')
-    doctor_visit_table = models.IntegerField(db_column='rf_DoctorVisitTableID')
+    doctor_visit_table = models.ForeignKey('HltDoctorVisitTable', models.DO_NOTHING, '+', db_column='rf_DoctorVisitTableID')
     lpu_doctor = models.IntegerField(db_column='rf_LPUDoctorID')
     mkab = models.ForeignKey('HltMkab', models.DO_NOTHING, db_column='rf_MKABID', related_name='visits')
     tap = models.ForeignKey('HltTap', models.DO_NOTHING, db_column='rf_TAPID', related_name='visits')
